@@ -31,7 +31,25 @@ class IPX800:
         self._request_timeout = request_timeout
         self._base_api_url = f"http://{host}:{port}/api/"
 
-        self._api_version = ""
+        self._api_version = None
+        self._firmware_version = None
+        self._mac_address = None
+
+        self.io_acpower_id = "ioDetectionAC_id"
+        self.ana_ipx_charge_period_id = "anaIPXChargePeriod_id"
+        self.ana_ipx_charge_app_id = "anaIPXChargeApp_id"
+        self.ana_ipx_charge_rules_id = "anaIPXChargeRules_id"
+        self.ana_ipx_charge_ebx_id = "anaIPXChargeEbx_id"
+        self.ana_ipx_charge_bsp_id = "anaIPXChargeBsp_id"
+        self.ana_ipx_cycle_period_id = "anaIPXCyclePeriod_id"
+        self.ana_ipx_cycle_app_id = "anaIPXCycleApp_id"
+        self.ana_ipx_cycle_rules_id = "anaIPXCycleRules_id"
+        self.ana_ipx_cycle_ebx_id = "anaIPXCycleEBX_id"
+        self.ana_heap_free_id = "anaHeapFree_id"
+        self.ana_delta_heap_free_id = "anaDeltaHeapFree_id"
+        self.ana_monitor_connections_id = "anaMonitorConnections_id"
+        self.ana_ipx_clock_id = "anaIPXClock_id"
+
         self._ipx_config = {}  # type: dict
         self._extensions_config = []  # type: list
         self._objects_config = []  # type: list
@@ -44,10 +62,26 @@ class IPX800:
             self._close_session = True
 
     @property
-    def api_version(self) -> str:
+    def api_version(self):
         """Return the API version."""
         return self._api_version
 
+    @property
+    def firmware_version(self):
+        """Return the firmware version."""
+        return self._firmware_version
+
+    @property
+    def mac_address(self):
+        """Return the MAC Address version."""
+        return self._mac_address
+
+    @property
+    async def ac_power(self) -> bool:
+        """Return if AC Power detected on the X-PSU, None if no X-PSU connected."""
+        response = await self._request_api("system/ipx")
+        return response.get(self.io_acpower_id) is True
+
     @property
     def ipx_config(self) -> dict:
         """Get the config of the IPX."""
@@ -122,10 +156,13 @@ class IPX800:
 
     async def get_ipx_info(self) -> dict:
         """Get IPX config."""
-        infos = await self._request_api("system/ipx/info")
-        self._api_version = infos["apiVersion"]
-        # TODO More properties
-        return infos
+        ipx_infos = await self._request_api("system/ipx/info")
+        infos = await self._request_api("system/info")
+        self._api_version = ipx_infos["apiVersion"]
+        self._firmware_version = infos["firmwareVersion"]
+        self._mac_address = infos["macAdress"]
+        self._host_name = infos["hostName"]
+        return ipx_infos
 
     async def global_get(self) -> dict:
         """Get all values from the IPX800 API."""
@@ -133,6 +170,13 @@ class IPX800:
         values.update({x["_id"]: x for x in await self._request_api("core/ana")})
         return values
 
+    async def reboot(self) -> None:
+        """Reboot the IPX800."""
+        try:
+            await self.update_io(self.ipx_config["ioIPXReset_id"], True)
+        except IPX800CannotConnectError:
+            print("IPX800V5 rebooted")
+
     # Get configs from PX API
     async def get_ipx_config(self) -> None:
         """Get IPX config."""
@@ -186,14 +230,14 @@ class IPX800:
         extensions = [
             x for x in self.extensions_config if x[API_CONFIG_TYPE] == ext_type
         ]
-        return extensions[ext_number - 1][API_CONFIG_PARAMS]
+        return extensions[ext_number][API_CONFIG_PARAMS]
 
     def get_ext_id(self, ext_type: str, ext_number: int) -> int:
         """Return the unique extension id generated by the IPX."""
         extensions = [
             x for x in self.extensions_config if x[API_CONFIG_TYPE] == ext_type
         ]
-        return extensions[ext_number - 1][API_CONFIG_ID]
+        return extensions[ext_number][API_CONFIG_ID]
 
     async def get_ext_states(self, ext_type: str, ext_id: int) -> dict:
         """Return all values of extension."""
@@ -202,12 +246,12 @@ class IPX800:
     def get_obj_config(self, obj_type: str, obj_number: int) -> dict:
         """Return the extension config."""
         extensions = [x for x in self.objects_config if x[API_CONFIG_TYPE] == obj_type]
-        return extensions[obj_number - 1][API_CONFIG_PARAMS]
+        return extensions[obj_number][API_CONFIG_PARAMS]
 
     def get_obj_id(self, obj_type: str, obj_number: int) -> str:
         """Return the unique object id generated by the IPX."""
         objs = [x for x in self.objects_config if x[API_CONFIG_TYPE] == obj_type]
-        return objs[obj_number - 1][API_CONFIG_ID]
+        return objs[obj_number][API_CONFIG_ID]
 
     # Get/Update commands
 
@@ -231,6 +275,7 @@ class IPX800:
             raise IPX800RequestError("Ana value need to be a int or a float type.")
         await self._request_api(f"core/ana/{id}", method="PUT", data={"value": value})
 
+    # Async defs
     async def close(self) -> None:
         """Close open client session."""
         if self._session and self._close_session:
